@@ -22,6 +22,7 @@
 #include <QtCore/QByteArray>
 #include <QtCore/QString>
 #include <gst/gstelement.h>
+#include <gst/gstbin.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -32,6 +33,7 @@ namespace Phonon
 {
 namespace Gstreamer
 {
+class MediaObject;
 class GstHelper
 {
 public:
@@ -40,6 +42,7 @@ public:
     static QByteArray property(GstElement *elem, const char *propertyName);
     static QByteArray name(GstObject *elem);
     static QString stateName(GstState);
+    static void writePipelineDot(MediaObject *media, const QString &type);
 };
 
 } // ns Gstreamer
